==> SnappEmailApiClient-0.3.19.zip: SnappEmailApiClient-0.3.19/snapp_email/endpoints/api_index/ApiIndex_1Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ApiIndex_1
from snapp_email.datacontract.utils import export_dict, fill


class ApiIndex_1Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'ApiIndex_1'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ApiIndex_1
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = ''.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.marg.bcsocial.api.index-v1.9+json',
            'Accept': 'application/vnd.marg.bcsocial.api.index-v1.9+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ApiIndex_1, response.json(), content_type=response.headers['Content-Type'])
    
    def get(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve information about the api index.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ApiIndex_1
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = ''.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.marg.bcsocial.api.index-v1.9+json',
            'Accept': 'application/vnd.marg.bcsocial.api.index-v1.9+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('get', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ApiIndex_1, response.json(), content_type=response.headers['Content-Type'])

==> SnappEmailApiClient-0.3.29.zip: SnappEmailApiClient-0.3.29/snapp_email/endpoints/api_index/ApiIndex_1Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ApiIndex_1
from snapp_email.datacontract.utils import export_dict, fill


class ApiIndex_1Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'ApiIndex_1'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ApiIndex_1
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = ''.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.marg.bcsocial.api.index-v1.9+json',
            'Accept': 'application/vnd.marg.bcsocial.api.index-v1.9+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ApiIndex_1, response.json(), content_type=response.headers['Content-Type'], silence_exceptions=self.api_client.silence_fill_exceptions)
    
    def get(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve information about the api index.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ApiIndex_1
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = ''.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.marg.bcsocial.api.index-v1.9+json',
            'Accept': 'application/vnd.marg.bcsocial.api.index-v1.9+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('get', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ApiIndex_1, response.json(), content_type=response.headers['Content-Type'], silence_exceptions=self.api_client.silence_fill_exceptions)
